################################
#                              #
# Author: Brenda Hanley        #
# Date Created: 2018          #
# License: MIT License         #
#                              #
################################
# We'd like to thank R online community and
# Matthew Plourde for with code structure
# and ideas to make this app possible.  

library(shiny)
library(shinyBS)

ui<-fluidPage(
  tags$head(tags$script("
                        window.onload = function() {
                        $('#mynavlist a:contains(\"Desired management goals\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Candidate models\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Selected population matrix model\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Stable proportions of the selected model\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Target abundances in time zero for the selected model\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Target abundances through time for the selected model\")').parent().addClass('disabled');
                        $('#mynavlist a:contains(\"Reintroduction out of SSD\")').parent().addClass('disabled');
                        };
                        Shiny.addCustomMessageHandler('activeNavs', function(nav_label) {
                        $('#mynavlist a:contains(\"' + nav_label + '\")').parent().removeClass('disabled');
                        });
                        ")),
  mainPanel(
    bsModal(id = 'startupModal', title = 'It is important for decision-makers, biologists, and modelers to recognize that not all details of a system need to be incorporated into a model of that system for the model to be useful for informing decisions. -Starfield 1997', trigger = '',
            size = 'large', p(HTML("
                                   <p></p>
                                   <p> This app isolates information from stable stage dynamics to suggest strategies for reintroduction. </p>
                                   <p> The mathematics underlying this app hinge on several simplifying assumptions.  Specifically, the math *does not* consider:<p/>
                                   <ol>
                                   <li> Carrying capacity </li>
                                   <li> Genetics  </li>
                                   <li> Density dependence </li>
                                   <li> Sex ratio </li>
                                   <li> Behaviour </li>
                                   <li> Any type of variation (demographic, environmental, sampling) </li>
                                   <li> Weather, climate, or seasonality </li>
                                   <li> Competition with other species </li>
                                   <li> Migration </li>
                                   <li> Predators </li>
                                   </ol>
                                   <p> This app isolates processes in population dynamics, and uses information from such dynamics to our managerial advantage.  However it is prudent to address these other important ecological considerations prior to enacting any reintroduction strategy.<p/>
                                   "))),
    width = 12
            ),
  
  titlePanel("Stable population theory to aid in reintroduction planning of an iteroparous species"),
  
  navlistPanel(selected = "My matrix requirements", id='mynavlist',
               tabPanel("My matrix requirements", 
                        fluidRow(
                          column(1,
                                 textInput(inputId="M1",label="Enter fertility of stage 1(0<=Dec.)."),
                                 textInput(inputId="OneTwo",label="Enter transition 1->2 (0<=Dec.<=1)."),
                                 textInput(inputId="OneThree",label="Enter transition 1->3 (0<Dec.<=1)."),
                                 textInput(inputId="OneFour",label="Enter transition 1->4 (0<Dec.<=1).")),
                          column(1, offset = 1,
                                 textInput(inputId="M2",label="Enter fertility of stage 2 (0<=Dec.)."),
                                 textInput(inputId="TwoTwo",label="Enter transition 2->2 (0<=Dec.<=1)."),
                                 textInput(inputId="TwoThree",label="Enter transition 2->3 (0<=Dec.<=1)."),
                                 textInput(inputId="TwoFour",label="Enter transition 2->4 (0<=Dec.<=1).")),
                          column(1, offset = 1,
                                 textInput(inputId="M3",label="Enter fertility of stage 3 (0<=Dec.)."),
                                 textInput(inputId="ThreeTwo",label="Enter transition 3->2 (0<=Dec.<=1)."),
                                 textInput(inputId="ThreeThree",label="Enter transition 3->3 (0<=Dec.<=1)."),
                                 textInput(inputId="ThreeFour",label="Enter transition 3->4 (0<=Dec.<=1).")),
                          column(1, offset = 1,
                                 textInput(inputId="M4",label="Enter fertility of stage 4 (0<=Dec.)."),
                                 textInput(inputId="FourTwo",label="Enter transition 4->2 (0<=Dec.<=1)."),
                                 textInput(inputId="FourThree",label="Enter transition 4->3 (0<=Dec.<=1)."),
                                 textInput(inputId="FourFour",label="Enter transition 4->4 (0<=Dec.<=1)."))),
                        actionButton("Lambda_done1", "Save matrix entries"),
                        actionButton("Helpbox1B","Help me determine what to enter"),
                        actionButton("Foundational", "Foundational matrix model information")
               ), # end sidebar panel  
               
               tabPanel("Desired management goals",
                        textInput(inputId="T",label="Enter the desired management timeline (Integer>1)."),
                        actionButton("Helpbox1a","Help me determine what to enter"),
                        textInput(inputId="GoalN",label="Enter the desired abundance of breeding females (Integer>0)."),
                        actionButton("Helpbox1b","Help me determine what to enter"),
                        textInput(inputId="CandidateModels",label="Enter the maximum number of candidate models to compare (Integer>0)."),
                        actionButton("Helpbox1d","Help me determine what to enter"),
                        selectInput("dimensionS",label="Matrix dimension",choices=c("Four-Stage Life History"=4),selected = "dimensionS"),
                        br(),
                        actionButton("Lambda_done", "Calculate candidate models")
               ), # end desired management panel
               
               tabPanel("Candidate models", textInput(inputId="B",label="Enter the row number for the candidate model of interest."),
                        br(),
                        actionButton("Candidate_model_done","Calculate detailed information for this model"),
                        br(),
                        h5("The top row is the model that you entered on the My matrix requirements tab"),
                        verbatimTextOutput("OPTIMAL.MODELS.ANIMALS1"),
                        h5("Each row represents a candidate model that may be used to achieve the desired goals."),
                        actionButton("Helpbox2","What does this even mean?"),
                        actionButton("Helpbox2b","Not seeing a big table of numbers? Click here"),
                        br(),
                        h5("Key to reading this table:"),
                        h6("Columns V1 though V4 represents reproduction for stages 1 through 4 (respectively)."),
                        h6("Column V5 through V8 represent transitions from stages 1-4 to stage 2 (respectively)."),
                        h6("Column V9 through V12 represent transitions from stages 1-4 to stage 3 (respectively)."),
                        h6("Column V13 through V16 represent transitions from stages 1-4 stage 4 (respectively)."),
                        h6("Column V17 represents the growth rate."),
                        h6("Column V18 represents the total number of females needed at T=0 to use stable population dynamics to achieve your management goal.")
               ), #end candidate panel
               
               tabPanel("Selected population matrix model", 
                        verbatimTextOutput("text22"),verbatimTextOutput("Model.matrix"),
                        br(),
                        h5("This is the population matrix model of the selected model."),
                        actionButton("Helpbox3","What is happening here?")
               ), #end matrix panel
               
               tabPanel("Stable proportions of the selected model", 
                        verbatimTextOutput("text2"),plotOutput("Pie.in.time.one"),verbatimTextOutput("Proportions.in.time.one"),
                        h5("These are the stable proportions for the selected model."),
                        br(),
                        h5("Table key:"),
                        h6("Row 1 represents the proportion of stage 1 when the population is in SSD."),
                        h6("Row 2 represents the proportion of stage 2 when the population is in SSD."),
                        h6("Row 3 represents the proportion of stage 3 when the population is in SSD."),
                        h6("Row 4 represents the proportion of stage 4 when the population is in SSD."),
                        actionButton("Helpbox4","How do I interpret this?"),
                        actionButton("Helpbox4a", "A cool twist to consider")
               ), #end proportions panel
               
               tabPanel("Target abundances in time zero for the selected model", 
                        verbatimTextOutput("text3"),verbatimTextOutput("Needed.in.time.one"),
                        br(),
                        h5("Here is the breakdown of abundances needed to achieve the desired management goal using stable population dynamics in conjunction with the selected model."),
                        h5("Table key:"),
                        h6("Row 1 represents the abundance of females in stage 1 at T=0."),
                        h6("Row 2 represents the abundance of females in stage 2 at T=0."),
                        h6("Row 3 represents the abundance of females in stage 3 at T=0."),
                        h6("Row 4 represents the abundance of females in stage 4 at T=0."),
                        h6("Row 5 represents the sum of females at T=0."),
                        actionButton("Helpbox5","What do these numbers mean?"),
                        actionButton("Helpbox5a","A cool twist to consider")
               ), #end target abundances in time zero panel
               
               tabPanel("Target abundances through time for the selected model", 
                        verbatimTextOutput("text1"),verbatimTextOutput("Needed.across.time"),
                        h5("Here is the stable progression of stage abundances through time."),
                        br(),
                        h5("Key:"),
                        h6("The release regime is the set of stage abundances at T=0 (the leftmost column)."),
                        h6("According to stable population theory, the individuals released at T=0 will reproduce to achieve target abundances by T=T (the rightmost column)."),
                        h6("Each column represents a single time unit."),
                        h6("Row 1 represents the number of females in stage 1."),
                        h6("Row 2 represents the number of females in stage 2."),
                        h6("Row 3 represents the number of females in stage 3."),
                        h6("Row 4 represents the number of females in stage 4."),
                        h6("Row 5 represents the sum of all females during the time unit"),
                        actionButton("Helpbox6","What do all those numbers mean?"),
                        actionButton("Helpbox6a","A cool twist to consider")
               ), # end abundances through time panel
               
               tabPanel("Reintroduction out of SSD", verbatimTextOutput("text23"),
                        textInput(inputId="Stage1",label="Enter the number of females in stage 1 (Integer>=0)."),
                        textInput(inputId="Stage2",label="Enter the number of females in stage 2 (Integer>=0)."),
                        textInput(inputId="Stage3",label="Enter the number of females in stage 3 (Integer>=0)."),
                        textInput(inputId="Stage4",label="Enter the number of females in stage 4 (Integer>=0)."),
                        br(),
                        plotOutput("Trajectories"),
                        br(),
                        h5("This plot overlays trajectories of releases regimes in and out of SSD."),
                        h6("The combination of matrices and initial conditions may produce surprising trajectories.  These transient dynamics may help or hurt your reintroduction. Depending on the initial conditions and model matrix, temporary oscillations may create deterministic trajectories that naturally approach extinction.  Alternatively, immediate population explosion could result in habitat degradation and subsequent die off.  By reintroducing in SSD, however, managers may rest assured that their actions are not contributing to oscillations, or that their actions aren't causing a population explosion.  Transient dynamics are not all bad.  Indeed, in certain situations, they can be beneficial to management.  If a manager wishes to terminate a species, inducing oscillations might be beneficial.  Alternatively, if managers wish to have population explosion from which to gather subjects for a second reintroduction (elsewhere), then producing more animals may be beneficial. It is up to the manager to decide whether the use of transient dynamics in lieu of stable dynamics constitute a benefit or risk in the context of their reintroduction goals.  For more information on transient dynamics and how these dynamics may be used to the advantage of managers, see Stott et al. 2010.")
               ) # end trajectory panel
               
  ) # end beginning of main panel
            ) # end main panel, end navlist panel, end navlist panel, End UI


server=function(input,output,session){
  toggleModal(session, "startupModal", toggle = "open")
  
  # This section is used for the Help buttons
  observeEvent(input$Foundational,{
    showModal(modalDialog(
      title="Foundational population matrix thinking",
      HTML("
           <p> Biological organisms reproduce.  Demography is the study of how abundances of biological organisms change over time.  A population matrix model is a specific model in demography that is used to study this change.  </p>
           <p> At their core, population matrix models are rooted in stable population theory, a mathematical theory that links vital rates and the system level dynamics that they produce.  Vital rates include a broad class of measurable quantities.  Familiar vital rates are the number of offspring per female, age at first breeding, life expectancy, etc.  In fact, insurance policies are often based on vital rates, as are measures of how human demographics change across continents. Demography is a versatile field.  It is interesting, sometimes predictable, but oh so useful.  </p>
           <p> We know a lot about the foundational equations of demography.  In fact, you could tell a demographer a few characteristics about individuals in a species, and that demographer could cite mathematical theory to tell you a bunch about the dynamics of the population without having laid eyes on a single individual. </p>
           <p> Population matrix models are matrices that contain a precise structure of vital rates.  For example, a simple life history is:</p>
           <p>Life history 1 here </p>
           <p> That figure corresponds to this set of equations:</p>
           <p> J(t) = A(t-1) * a13</p>
           <p> S(t) = J(t-1) * a21</p>
           <p> A(t) = S(t-1) * a32 + A(t-1) * a33</p>
           <p> That second equation says that the number of subadults in the system this year S(t) is equivalent to the number of juveniles that were in the system last year J(t-1) that survived and advanced in their life history (a21).   The other statements have similar interpretations.  </p>
           <p> A population matrix model can be thought of as a mathematical summary or ingenious accounting system of how individuals transition through their life history over time.
           </p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox1a,{
    showModal(modalDialog(
      title="Desired timeline",
      HTML("
           <p> This is the number of time units (of management interest), written in the units that are appropriate to the life history of the modeled species. For example, the unit could represent months, years, 90-day segments (i.e. seasons), or some other species-appropriate unit.   </p>
           <p> Here are a few examples: </p>
           <ol>
           <li>Let a life history have a time unit equal to 1 year.  An entry of 10 will give you results at the end of 10 years.</li>
           <li>Let a life history have a time unit of 4 months.  An entry of 3 would represent 4*3=12 months of projection. </li>
           <li>Let a life history have a time unit equal to 4 months.  Let the management timeframe of interest be equal to 10 years.  An entry of 30 (4*30=120 months; which is 10 years) is appropriate.</li>
           </ol>
           </p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox1b,{
    showModal(modalDialog(
      title="Desired breeding female abundance",
      HTML("
           <p> This is the number of breeding females that managers desire to exist in the population by the end of the restoration timeframe.  </p>
           <p> Remember, this population matrix model only models females, so your total desired abundances must reflect the breeding sex ratio of your species.  For example, assuming a 1:1 sex ratio, then 800 breeding females equates to 800 mating pairs.</p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox1B,{
    showModal(modalDialog(
      title="Vital rates of the population matrix model",
      HTML("
           <p> Reproduction parameters: The top row represents the reproduction in the life history.  Each element in this row may be parameterized as fertility (actual reproduction) or fecundity (maximum reproduction).  Reproduction elements are in the units of per breeding female, per time period.  For additional information, refer to Caswell 2001, pgs. 10 and 171.  </p>
           <p> Transition parameters: All entries that do not appear in the top row represent transitions through the life stages.  A transition that begins at one stage and ends in a different stage represents the average probablity that a female will survive the time unit and transition to the latter stage.  Alternatively, a transition that begins at one stage and ends in the same stage represents the average probablity that a female will survive the time unit and remain in that same stage.  For additional information, refer to Caswell 2001, pgs. 10 and 171.</p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox1d,{
    showModal(modalDialog(
      title="Maximum number of candidate models to compare",
      HTML("
           <p> Growth rates and vital rates are not mathematically one-to-one. That is, several sets of vital rates may yield an identical growth rate.  In other words, there are a bunch of mathematical ways to arrive at the same goal.  </p>
           <p> Math is internally consistent, so from the math perspective, it really doesn't matter what route you take; if you arrive at your desired destination, then, well, that route works.  One of the coolest things about this app is that we use this very idea to suggest alternative methods to achieve a reintroduction goal, even if some obstacle exists that might stymie the most direct route. </p>
           <p> This entry is not a desired management goal per se; it is just a way to pare down the number of alternative routes to compare.  In fact, you could compare all the routes that lead to the goal if you want. There are infinite number of routes! But at some point, you might want to do something else, like go to lunch, or go for a walk.  So entering a number here just lets you look at a manageable subset.</p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox2,{
    showModal(modalDialog(
      title="Candidate models (aka: management regimes)",
      HTML("
           <p> This tab suggests several mathematically viable routes that may be used to align a release with stable population dynamics. </p>
           <p> The first row represents your model of interest.  All other rows represent viable mathematical models that are similar in life history structure to your model.  Starting on the left-hand side of each row, the sequential numbers represent the matrix elements.  The second to last number in each row is the desired growth rate.  The last number in each row shows the total number of females that need to be released at the onset of reintroduction to align your reintroduction with results from stable population theory.  </p>
           <p> The last column gives the metaphorical *cost* of each model.  For example, some strategies require the initial release of 400 females, while others may require the initial release of 600.  How can this be?  Well there are differential costs associated with differing depressions in vital rates.  Indeed, sensitivity analysis in model matrices allow practitioners to assess how influential each matrix element is to the overall population dynamics (see Caswell 2001, pg. 208).  In the context of reintroduction, depressions in survival or fertility at certain life stages may differentially influence growth rates, which differentially impact release abundances.</p>
           <p> It might well be the case that managers cannot alleviate impactful depressions at places in the life history, and therefore need to reintroduce more individuals to make up it.  That is, some unavoidable habitat, genetic, biological, predation, or competing land use may function to depress survival (for example) at any given reintroduction site.  Uncontrollable conditions at the reintroduction site may mean managers will be faced with planning reintroductions in suboptimal conditions.  In such cases, the host of candidate models suggests alternative release strategies that are aligned with similar model matrices.  The best option for management might not be the model at hand, but rather the model matrix most closely represents what the life history of the species would be at the reintroduction site. </p>
           <p>This array of candidate models suggests ways to prime a restoration in accordance with stable dynamics despite situational challenges.</p>
           "),
      easyClose=TRUE))})
  observeEvent(input$Helpbox2b,{
    showModal(modalDialog(
      title="Did you get an error?",
      HTML("<p>You got this error because the thousands upon thousands of simulations that we ran to obtain possible matrices did not produce any with your same vital rates inputs. </p>
           <p>You have two options: <p/>
           <ol>
           <li>Go back to the My matrix requirements tab and change your matrix elements, resave, then revisit this page, or </li>
           <li>Email us and ask us to run more simulations to bolster the simulated dataset in the structure of your model of interest.  This run time is long, so it might take us a minute, but we are happy to do that for you.  But for starters, we had to draw the line somewhere.</li>
           </ol>"),
      easyClose=TRUE))})
  observeEvent(input$Helpbox3,{
    showModal(modalDialog(
      title="Your selected management regime (aka: the habitat maintenance component when using stable dynamics for reintroduction)",
      HTML("<p> This displays your selected candidate model in familiar model matrix form.</p>
           <p> Stable population dynamics require a static model matrix (Caswell 2001, pg. 87). A reintroduction release strategy that is based on stable dynamics to achieve a goal requires a static interim model matrix. Managers may need to plan to manage some aspect of the habitat through time to ensure that the reintroduction site produces static conditions that are consistent with the model matrix.  </p>
           "),       
      easyClose=TRUE))})
  observeEvent(input$Helpbox4,{
    showModal(modalDialog(
      title="Here is the stable stage distributions (SSD) of your selected model",
      HTML("<p> This tab shows the proportion of females that need to exist in each stage for the population to grow according to stable population theory.</p>
           <p> Think of the stable stage proportions like this.  Our recipe calls for X proportion of this ingredient, Y proportion of that ingredient (and so on).  If use those proportions, we have set ourselves up to create our desired dish.  Only here, the ingredients are not sugar or flour or whatever, but abundances of females in each stage.  For example, stable population theory says that we need X proportion of stage 1, Y proportion of stage 2, (etc.) to make a stable population.  The proportions hinge on the life history of the species.  If you select a different candidate model, these proportions will update.  </p>"),
      easyClose=TRUE))})
  observeEvent(input$Helpbox4a,{
    showModal(modalDialog(
      title="Here is a cool twist",
      HTML("<p> These are proportions of stages in a stable system.  You would scale up or down these proportions to get a different size population.<p/>"),
      easyClose=TRUE))})
  observeEvent(input$Helpbox5,{
    showModal(modalDialog(
      title="Abudances needed at time zero",
      "This tab gives the number of females needed to be released at time T=0 to *theoretically* produce your desired restoration goals using stable population theory by time T=T.",
      easyClose=TRUE))})
  observeEvent(input$Helpbox5a,{
    showModal(modalDialog(
      title="Is this too many individuals?",
      HTML("<p> You have four options:  <p/>
           <ol>
           <li> Relax your timeline expectations. </li>
           <li> Relax your abundance expectations.  </li>
           <li> Relax your growth rate expectations.   </li>
           <li>  Investigate the possibility of using transient dynamics to your advantage.  Stott et al. 2010.  </li>
           </ol>
           <p> As you can see, the math can help in many ways, but you are still going to have to make several planning decisions!</p>
           "), 
      easyClose=TRUE))})
  observeEvent(input$Helpbox6,{
    showModal(modalDialog(
      title="Abundances through time",
      "Recall the units of your time frame.  This tab demonstrates how the population will *theoretically* change from the onset of stable-population reintroduction through the end of your desired timeframe.  Time flows from left to right.",
      easyClose=TRUE))})
  observeEvent(input$Helpbox6a,{
    showModal(modalDialog(
      title="Here is a recipe to monitoring the stable dynamics over time",
      HTML("<p> How do we know if our reintroduction is on track?  You can monitor the progress of the stable abundance through time using these numbers.  What if we find that too few females exist in a stage at a specific time?  This gives the exact recipe for interim supplementation to recover stable dynamics for each stage at each time. </p>
           <p> As well, you could use this information to identify stable stage abundances for many other monitoring or management prescriptions. <p/>"),
      easyClose=TRUE))})
  
  # This section turns on the nav panels
  observe({
    if (input$Lambda_done1 > 0) {
      session$sendCustomMessage('activeNavs', 'Desired management goals')}}) 
  observe({
    if (input$Lambda_done > 0) {
      session$sendCustomMessage('activeNavs', 'Candidate models')}})
  observe({
    if (input$Candidate_model_done > 0) {
      session$sendCustomMessage('activeNavs', 'Stable proportions of the selected model')}})
  observe({
    if (input$Candidate_model_done > 0) {
      session$sendCustomMessage('activeNavs', 'Target abundances in time zero for the selected model')}})
  observe({
    if (input$Candidate_model_done > 0) {
      session$sendCustomMessage('activeNavs', 'Target abundances through time for the selected model')}})
  observe({
    if (input$Candidate_model_done > 0) {
      session$sendCustomMessage('activeNavs', 'Reintroduction out of SSD')}})
  observe({
    if (input$Candidate_model_done > 0) {
      session$sendCustomMessage('activeNavs', 'Selected population matrix model')}})
  
  # This is a header on each tab after a model has been selected
  output$text1 <- renderText({paste("You have selected candidate model",input$B,":")})
  output$text2 <- renderText({paste("You have selected candidate model",input$B,":")})
  output$text3 <- renderText({paste("You have selected candidate model",input$B,":")})
  output$text22 <- renderText({paste("You have selected candidate model",input$B,":")})
  output$text23 <- renderText({paste("You have selected candidate model",input$B,":")}) 
  
  # These sections form the body each tab
  
  # TAB 1 
  output$Model.matrix=renderPrint({
    
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    
    # Beginning tab specific
    vector=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    model.matrix=matrix(0,4,4)
    row1=c(vector[1],vector[2],vector[3],vector[4])
    row2=c(vector[5],vector[6],vector[7],vector[8])
    row3=c(vector[9],vector[10],vector[11],vector[12])
    row4=c(vector[13],vector[14],vector[15],vector[16])
    model.matrix=rbind(row1,row2,row3,row4)    
    colnames(model.matrix)=NULL
    print(model.matrix)
  }) # end model matrix tab
  
  output$Pie.in.time.one=renderPlot({
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    
    # Beginning tab specific    
    selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    # Create the model matrix							
    r1=as.numeric(selection[1])
    r2=as.numeric(selection[2])
    r3=as.numeric(selection[3])
    r4=as.numeric(selection[4])
    aaa=as.numeric(selection[5])
    baa=as.numeric(selection[6])
    ca=as.numeric(selection[7])
    da=as.numeric(selection[8])
    ea=as.numeric(selection[9])
    fa=as.numeric(selection[10])
    gga=as.numeric(selection[11])
    ha=as.numeric(selection[12])
    iiaa=as.numeric(selection[13])
    jja=as.numeric(selection[14])
    kka=as.numeric(selection[15])
    lla=as.numeric(selection[16])    
    top=c(r1,r2,r3,r4)
    mid=c(aaa,baa,ca,da)
    mid2=c(ea,fa,gga,ha)
    bot1=c(iiaa,jja,kka,lla)
    L=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
      L1=eigen(L)$values[1]
      W1=matrix(c(eigen(L)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        	
    Proportions.for.W[1]=Re(W1[1]/sum(W1))						
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))	
    Proportions.for.W[4]=Re(W1[4]/sum(W1))										
    ProportionS=numeric(4)              
    ProportionS[1]=Proportions.for.W[1]
    ProportionS[2]=Proportions.for.W[2]
    ProportionS[3]=Proportions.for.W[3]
    ProportionS[4]=Proportions.for.W[4]
    
    slices=c(ProportionS[1],ProportionS[2],ProportionS[3],ProportionS[4])
    lab <- c("Stage 1", "Stage 2", "Stage 3","Stage 4")
    pie(slices,labels = lab, col=rainbow(length(lab)),main="Stable stage proportions")
  }) # end pie in time one tab
  
  output$Needed.in.time.one=renderPrint({
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    # Beginning tab specific    
    selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    # Create the model matrix							
    r1=as.numeric(selection[1])
    r2=as.numeric(selection[2])
    r3=as.numeric(selection[3])
    r4=as.numeric(selection[4])
    aaa=as.numeric(selection[5])
    baa=as.numeric(selection[6])
    ca=as.numeric(selection[7])
    da=as.numeric(selection[8])
    ea=as.numeric(selection[9])
    fa=as.numeric(selection[10])
    gga=as.numeric(selection[11])
    ha=as.numeric(selection[12])
    iiaa=as.numeric(selection[13])
    jja=as.numeric(selection[14])
    kka=as.numeric(selection[15])
    lla=as.numeric(selection[16])    
    top=c(r1,r2,r3,r4)
    mid=c(aaa,baa,ca,da)
    mid2=c(ea,fa,gga,ha)
    bot1=c(iiaa,jja,kka,lla)
    L=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L)$values[1]
    W1=matrix(c(eigen(L)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        	
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))											
    
    N=matrix(0,4,(as.numeric(input$T)+1))						
    
    # If 4th stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 3RD stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[4])==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 2ND stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 1ST stage reproduces							
    if (as.numeric(selection[2])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    TotalN[1]=sum(floor(N[4,1])+floor(N[3,1])+floor(N[2,1])+floor(N[1,1]))        
    
    out=matrix(0,5,1)
    out[1,1]=floor(N[1,1])
    out[2,1]=floor(N[2,1])
    out[3,1]=floor(N[3,1])
    out[4,1]=floor(N[4,1])
    out[5,1]=TotalN[x]
    out
  }) # end needed in time one tab
  
  output$Proportions.in.time.one=renderPrint({
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    
    # Beginning tab specific    
    selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    # Create the model matrix							
    r1=as.numeric(selection[1])
    r2=as.numeric(selection[2])
    r3=as.numeric(selection[3])
    r4=as.numeric(selection[4])
    aaa=as.numeric(selection[5])
    baa=as.numeric(selection[6])
    ca=as.numeric(selection[7])
    da=as.numeric(selection[8])
    ea=as.numeric(selection[9])
    fa=as.numeric(selection[10])
    gga=as.numeric(selection[11])
    ha=as.numeric(selection[12])
    iiaa=as.numeric(selection[13])
    jja=as.numeric(selection[14])
    kka=as.numeric(selection[15])
    lla=as.numeric(selection[16])    
    top=c(r1,r2,r3,r4)
    mid=c(aaa,baa,ca,da)
    mid2=c(ea,fa,gga,ha)
    bot1=c(iiaa,jja,kka,lla)
    L=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L)$values[1]
    W1=matrix(c(eigen(L)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						       
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))	
    Proportions.for.W[4]=Re(W1[4]/sum(W1))											
    ProportionS=numeric(4)              
    ProportionS[1]=Proportions.for.W[1]
    ProportionS[2]=Proportions.for.W[2]
    ProportionS[3]=Proportions.for.W[3]
    ProportionS[4]=Proportions.for.W[4]
    slices=matrix(0,4,1)
    slices[1,1]=ProportionS[1]
    slices[2,1]=ProportionS[2]
    slices[3,1]=ProportionS[3]
    slices[4,1]=ProportionS[4]
    slices
  }) # end proportions in time one tab
  
  output$Needed.across.time=renderPrint({  
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    # Beginning tab specific    
    selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    # Create the model matrix							
    r1=as.numeric(selection[1])
    r2=as.numeric(selection[2])
    r3=as.numeric(selection[3])
    r4=as.numeric(selection[4])
    aaa=as.numeric(selection[5])
    baa=as.numeric(selection[6])
    ca=as.numeric(selection[7])
    da=as.numeric(selection[8])
    ea=as.numeric(selection[9])
    fa=as.numeric(selection[10])
    gga=as.numeric(selection[11])
    ha=as.numeric(selection[12])
    iiaa=as.numeric(selection[13])
    jja=as.numeric(selection[14])
    kka=as.numeric(selection[15])
    lla=as.numeric(selection[16])    
    top=c(r1,r2,r3,r4)
    mid=c(aaa,baa,ca,da)
    mid2=c(ea,fa,gga,ha)
    bot1=c(iiaa,jja,kka,lla)
    L=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L)$values[1]
    W1=matrix(c(eigen(L)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        	
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))	
    Proportions.for.W[4]=Re(W1[4]/sum(W1))											
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    
    # If 4th stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 3RD stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[4])==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 2ND stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 1ST stage reproduces							
    if (as.numeric(selection[2])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}   
    
    Total=colSums(N)
    TABLE=rbind(N,Total)
    TABLE
  }) # end abundances over time tab
  
  output$Trajectories=renderPlot({
    dom=read.table("DOM_EVALUES_4_Master.txt")
    if (as.numeric(input$M1)!=0){
      MIN=max(.1,as.numeric(input$M1)-.5)
      MAX=as.numeric(input$M1)+.5
      dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
    if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
    
    if (as.numeric(input$M2)!=0){
      MIN=max(.1,as.numeric(input$M2)-.5)
      MAX=as.numeric(input$M2)+.5
      dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
    if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
    
    if (as.numeric(input$M3)!=0){
      MIN=max(.1,as.numeric(input$M3)-.5)
      MAX=as.numeric(input$M3)+.5
      dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
    if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
    
    if (as.numeric(input$M4)!=0){
      MIN=max(0,as.numeric(input$M4)-.5)
      MAX=min(1,as.numeric(input$M4)+.5)
      dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
    if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
    
    if (as.numeric(input$OneTwo)!=0){
      MIN=max(0,as.numeric(input$OneTwo)-.5)
      MAX=min(1,as.numeric(input$OneTwo)+.5)
      dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
    if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
    
    if (as.numeric(input$TwoTwo)!=0){
      MIN=max(0,as.numeric(input$TwoTwo)-.5)
      MAX=min(1,as.numeric(input$TwoTwo)+.5)
      dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
    if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
    
    if (as.numeric(input$ThreeTwo)!=0){
      MIN=max(0,as.numeric(input$ThreeTwo)-.5)
      MAX=min(1,as.numeric(input$ThreeTwo)+.5)
      dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
    
    if (as.numeric(input$FourTwo)!=0){
      MIN=max(0,as.numeric(input$FourTwo)-.5)
      MAX=min(1,as.numeric(input$FourTwo)+.5)
      dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
    if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
    
    if (as.numeric(input$OneThree)!=0){
      MIN=max(0,as.numeric(input$OneThree)-.5)
      MAX=min(1,as.numeric(input$OneThree)+.5)
      dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
    if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
    
    if (as.numeric(input$TwoThree)!=0){
      MIN=max(0,as.numeric(input$TwoThree)-.5)
      MAX=min(1,as.numeric(input$TwoThree)+.5)
      dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
    if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
    
    if (as.numeric(input$ThreeThree)!=0){
      MIN=max(0,as.numeric(input$ThreeThree)-.5)
      MAX=min(1,as.numeric(input$ThreeThree)+.5)
      dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
    if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
    
    if (as.numeric(input$FourThree)!=0){
      MIN=max(0,as.numeric(input$FourThree)-.5)
      MAX=min(1,as.numeric(input$FourThree)+.5)
      dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
    if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
    
    if (as.numeric(input$OneFour)!=0){
      MIN=max(0,as.numeric(input$OneFour)-.5)
      MAX=min(1,as.numeric(input$OneFour)+.5)
      dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
    if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
    
    if (as.numeric(input$TwoFour)!=0){
      MIN=max(0,as.numeric(input$TwoFour)-.5)
      MAX=min(1,as.numeric(input$TwoFour)+.5)
      dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
    if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
    
    if (as.numeric(input$ThreeFour)!=0){
      MIN=max(0,as.numeric(input$ThreeFour)-.5)
      MAX=min(1,as.numeric(input$ThreeFour)+.5)
      dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
    if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
    
    if (as.numeric(input$FourFour)!=0){
      MIN=max(0,as.numeric(input$FourFour)-.5)
      MAX=min(1,as.numeric(input$FourFour)+.5)
      candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
    if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
    
    # Main body 
    
    ref=candidates
    
    NUM.CANDIDATE.MODELS=length(candidates[,1]) 
    First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
    First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
    TotalN=numeric(as.numeric(input$T)+1)
    
    if (dim(ref)[1]!=0){    
      MODEL.OPTION=0
      for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
        MODEL.OPTION=MODEL.OPTION+1
        
        # Create the model matrix							
        r1=candidates[g,1]
        r2=candidates[g,2]
        r3=candidates[g,3]
        r4=candidates[g,4]
        a=candidates[g,5]
        b=candidates[g,6]
        c=candidates[g,7]
        d=candidates[g,8]
        e=candidates[g,9]
        f=candidates[g,10]
        gg=candidates[g,11]
        hh=candidates[g,12]
        ii=candidates[g,13]
        jj=candidates[g,14]
        kk=candidates[g,15]
        ll=candidates[g,16]
        top=c(r1,r2,r3,r4)
        mid=c(a,b,c,d)
        mid2=c(e,f,gg,h)
        bot1=c(ii,jj,kk,ll)        
        L=rbind(top,mid,mid2,bot1)
        
        # Get the eigenvalues of the matrix only if there are any to get
        if(dim(ref)[1]!=0){
          L1=eigen(L)$values[1]
          W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
        if(dim(ref)[1]==0){
          L1=0; W1=matrix(c(1,1,1),4,1)}
        
        Proportions.for.W=numeric(4)						        	
        Proportions.for.W[1]=Re(W1[1]/sum(W1))							
        Proportions.for.W[2]=Re(W1[2]/sum(W1))						
        Proportions.for.W[3]=Re(W1[3]/sum(W1))
        Proportions.for.W[4]=Re(W1[4]/sum(W1))						
        
        N=matrix(0,4,(as.numeric(input$T)+1))	
        
        # If 4th stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 3RD stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,4]==0){
              N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 2ND stage reproduces							
        if (candidates[g,1]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}} # end 
        
        # If 1ST stage reproduces							
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
              TotalN=numeric(((as.numeric(input$T)+1)))
              TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}} # end 
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end     
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        #						
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
                TotalN[as.numeric(input$T)+1]=Y
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end 
        #							
        if (candidates[g,1]==0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                # fill in the last value
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]==0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]==0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              }}}} # end        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]==0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
                TotalN[as.numeric(input$T)+1]=Y
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                # fill in the last value
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              }}}} # end        
        
        #							
        if (candidates[g,1]!=0){
          if (candidates[g,2]!=0){
            if (candidates[g,3]!=0){
              if (candidates[g,4]!=0){
                # split of animals given the SSD and the goal
                Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
                TotalN[as.numeric(input$T)+1]=Y
                N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
                N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
                N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
                N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              }}}} # end        
        
        ##################
        for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
          N[4,x]=floor(Re(N[4,x+1]/L1))
          N[3,x]=floor(Re(N[3,x+1]/L1))
          N[2,x]=floor(Re(N[2,x+1]/L1))
          N[1,x]=floor(Re(N[1,x+1]/L1))
        } # Generating SSD abundances back through time 
        
        # Set the negative numbers to zero
        for (ww in 1:length(N[1,])){
          for (ccc in 1:4){									
            if (N[ccc,ww]<0){N[ccc,ww]=0}}}
        
        for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
          TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
        
        First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
        First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
        candidates[g,18]=floor(TotalN[1])							
      } # end g loop
      
    } # end no candidates loop
    
    # pick out the top best models given user input
    if (dim(ref)[1]!=0){
      if (length(candidates[,1])!=1){
        First.step.cohort[6,]=1:length(candidates[,1])
        best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
        models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
      
      if (length(candidates[,1])==1){
        First.step.cohort[6,1]=1
        best=First.step.cohort[6,1]
        models.to.pick.out=best}
    }
    if (dim(ref)[1]==0){models.to.pick.out=1}
    
    #Calculate everything for my model, then add it into the top of the best models
    my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
               as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
               as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
               as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
    r11=as.numeric(input$M1)
    r21=as.numeric(input$M2)
    r31=as.numeric(input$M3)
    r41=as.numeric(input$M4)
    
    a1=as.numeric(input$OneTwo)
    b1=as.numeric(input$TwoTwo)
    c1=as.numeric(input$ThreeTwo)
    d1=as.numeric(input$FourTwo)
    
    f1=as.numeric(input$OneThree)
    gg1=as.numeric(input$TwoThree)
    h1=as.numeric(input$ThreeThree)
    i1=as.numeric(input$FourThree)
    
    k1=as.numeric(input$OneFour)
    l1=as.numeric(input$TwoFour)
    m1=as.numeric(input$ThreeFour)
    n1=as.numeric(input$FourFour)
    
    top=c(r11,r21,r31,r41)
    mid=c(a1,b1,c1,d1)
    mid2=c(f1,gg1,h1,i1)
    bot1=c(k1,l1,m1,n1)
    L.mine=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L.mine)$values[1]
    W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))						
    Proportions.for.W[4]=Re(W1[4]/sum(W1))						
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    # If 4th stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 3RD stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M4)==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 2ND stage reproduces							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    # If 1ST stage reproduces							
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(input$M1)==0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)==0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)==0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(input$M1)!=0){
      if (as.numeric(input$M2)!=0){
        if (as.numeric(input$M3)!=0){
          if (as.numeric(input$M4)!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    ####################################################################################
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}
    
    total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
    
    aaa=as.numeric(input$M1)
    bbb=as.numeric(input$M2)
    cccc=as.numeric(input$M3)
    ddd=as.numeric(input$M4)
    fff=as.numeric(input$OneTwo)
    ggg=as.numeric(input$TwoTwo)
    hhh=as.numeric(input$ThreeTwo)
    iii=as.numeric(input$FourTwo)
    kkk=as.numeric(input$OneThree)
    lll=as.numeric(input$TwoThree)
    mmm=as.numeric(input$ThreeThree)
    nnn=as.numeric(input$FourThree)
    ppp=as.numeric(input$OneFour)
    qqq=as.numeric(input$TwoFour)
    rrr=as.numeric(input$ThreeFour)
    sss=as.numeric(input$FourFour)    
    
    mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
    new=rbind(mine,dom[1,]) 
    if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
    if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
    
    # End main body  
    # Beginning tab specific    
    selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
    # Create the model matrix							
    r1=as.numeric(selection[1])
    r2=as.numeric(selection[2])
    r3=as.numeric(selection[3])
    r4=as.numeric(selection[4])
    aaa=as.numeric(selection[5])
    baa=as.numeric(selection[6])
    ca=as.numeric(selection[7])
    da=as.numeric(selection[8])
    ea=as.numeric(selection[9])
    fa=as.numeric(selection[10])
    gga=as.numeric(selection[11])
    ha=as.numeric(selection[12])
    iiaa=as.numeric(selection[13])
    jja=as.numeric(selection[14])
    kka=as.numeric(selection[15])
    lla=as.numeric(selection[16])    
    top=c(r1,r2,r3,r4)
    mid=c(aaa,baa,ca,da)
    mid2=c(ea,fa,gga,ha)
    bot1=c(iiaa,jja,kka,lla)
    L=rbind(top,mid,mid2,bot1)
    
    # Get the eigenvalues of the matrix
    L1=eigen(L)$values[1]
    W1=matrix(c(eigen(L)$vectors[,1]),4,1)
    
    Proportions.for.W=numeric(4)						        	
    Proportions.for.W[1]=Re(W1[1]/sum(W1))							
    Proportions.for.W[2]=Re(W1[2]/sum(W1))						
    Proportions.for.W[3]=Re(W1[3]/sum(W1))	
    Proportions.for.W[4]=Re(W1[4]/sum(W1))											
    
    N=matrix(0,4,(as.numeric(input$T)+1))
    
    # If 4th stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 3RD stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[4])==0){
          N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 2ND stage reproduces							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}} # end 
    
    # If 1ST stage reproduces							
    if (as.numeric(selection[2])==0){
      if (as.numeric(selection[3])==0){
        if (as.numeric(selection[4])==0){
          N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
          TotalN=numeric(((as.numeric(input$T)+1)))
          TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}} # end 
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end     
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #						
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
            TotalN[as.numeric(input$T)+1]=Y
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end 
    #							
    if (as.numeric(selection[1])==0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            # fill in the last value
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])==0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])==0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])==0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
            TotalN[as.numeric(input$T)+1]=Y
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            # fill in the last value
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          }}}} # end        
    #							
    if (as.numeric(selection[1])!=0){
      if (as.numeric(selection[2])!=0){
        if (as.numeric(selection[3])!=0){
          if (as.numeric(selection[4])!=0){
            # split of animals given the SSD and the goal
            Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
            TotalN[as.numeric(input$T)+1]=Y
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}}} # end        
    
    for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
      N[4,x]=floor(Re(N[4,x+1]/L1))
      N[3,x]=floor(Re(N[3,x+1]/L1))
      N[2,x]=floor(Re(N[2,x+1]/L1))
      N[1,x]=floor(Re(N[1,x+1]/L1))
    } # Generating SSD abundances back through time 
    
    # Set the negative numbers to zero
    for (ccc in 1:4){									
      if (N[ccc,1]<0){N[ccc,1]=0}}   
    
    # prepare the plot
    xx=0:(as.numeric(input$T))
    plot(xx,N[1,],xlim=c(0, as.numeric(input$T)), ylim=c(0,2*max(max(N[4,]),max(N[3,]),max(N[2,]),max(N[1,]))),xlab="Time",
         main="Abundances through time in and out of SSD for the model of interest",ylab="Population size",col=1,type="l",cex=2)
    points(xx,N[2,],ylim=" ",xlab="Time",ylab="",col=3,type="l",cex=2)
    points(xx,N[3,],ylim=" ",xlab="Time",ylab="",col=4,type="l",cex=2)
    points(xx,N[4,],ylim=" ",xlab="Time",ylab="",col=5,type="l",cex=2)
    legend(0,2*max(max(N[4,]),max(N[3,]),max(N[2,]),max(N[1,])),
    c("Stage 1 in SSD", "Stage 2 in SSD", "Stage 3 in SSD","Stage 4 in SSD", 
      "Stage 1 out of SSD","Stage 2 out of SSD","Stage 3 out of SSD","Stage 4 out of SSD"), 
    lty=c(1,1,1,1,2,2,2,2), col=c(1,3,4,5,1,3,4,5))
  
  # Now add the unstable trajectories
  selection=as.numeric(OPTIMAL.MODELS.ANIMALS1[as.numeric(input$B),])
  A=matrix(0,4,4)
  A[1,1]=as.numeric(selection[1])
  A[1,2]=as.numeric(selection[2])
  A[1,3]=as.numeric(selection[3])
  A[1,4]=as.numeric(selection[4])    
  
  A[2,1]=as.numeric(selection[5])
  A[2,2]=as.numeric(selection[6])
  A[2,3]=as.numeric(selection[7])
  A[2,4]=as.numeric(selection[8])    
  
  A[3,1]=as.numeric(selection[9])
  A[3,2]=as.numeric(selection[10])
  A[3,3]=as.numeric(selection[11])
  A[3,4]=as.numeric(selection[12])    
  
  A[4,1]=as.numeric(selection[13])
  A[4,2]=as.numeric(selection[14])
  A[4,3]=as.numeric(selection[15])
  A[4,4]=as.numeric(selection[16])    
  
  N1=as.numeric(input$Stage1)
  N2=as.numeric(input$Stage2)
  N3=as.numeric(input$Stage3)
  N4=as.numeric(input$Stage4)
  
  N=matrix(0,4,as.numeric(input$T)+1)
  init=matrix(c(N1,N2,N3,N4),4,1)
  
  for (i in 1:(as.numeric(input$T))){
    N[,1]=ceiling(init)
    N[,i+1]=ceiling(A%*%N[,i])}
  
  points(xx,N[1,],ylim=" ", xlab="Time", ylab="", col=1,type="l",lty=2)
  points(xx,N[2,],ylim=" ", xlab="Time", ylab="", col=3,type="l",lty=2)
  points(xx,N[3,],ylim=" ", xlab="Time", ylab="", col=4,type="l",lty=2)
  points(xx,N[4,],ylim=" ", xlab="Time", ylab="", col=5,type="l",lty=2)
  
  }) # end trajectories tab

output$OPTIMAL.MODELS.ANIMALS1=renderPrint({
  dom=read.table("DOM_EVALUES_4_Master.txt")
  if (as.numeric(input$M1)!=0){
    MIN=max(.1,as.numeric(input$M1)-.5)
    MAX=as.numeric(input$M1)+.5
    dom1=dom[MIN<=dom[,1] & dom[,1]<=MAX,]}
  if (as.numeric(input$M1)==0){dom1=dom[dom[,1]==0,]}
  
  if (as.numeric(input$M2)!=0){
    MIN=max(.1,as.numeric(input$M2)-.5)
    MAX=as.numeric(input$M2)+.5
    dom2=dom1[MIN<=dom1[,2] & dom1[,2]<=MAX,]}
  if (as.numeric(input$M2)==0){dom2=dom1[dom1[,2]==0,]}
  
  if (as.numeric(input$M3)!=0){
    MIN=max(.1,as.numeric(input$M3)-.5)
    MAX=as.numeric(input$M3)+.5
    dom3=dom2[MIN<=dom2[,3] & dom2[,3]<=MAX,]}
  if (as.numeric(input$M3)==0){dom3=dom2[dom2[,3]==0,]}
  
  if (as.numeric(input$M4)!=0){
    MIN=max(0,as.numeric(input$M4)-.5)
    MAX=min(1,as.numeric(input$M4)+.5)
    dom4=dom3[MIN<=dom3[,4] & dom3[,4]<=MAX,]}
  if (as.numeric(input$M4)==0){dom4=dom3[dom3[,4]==0,]}
  
  if (as.numeric(input$OneTwo)!=0){
    MIN=max(0,as.numeric(input$OneTwo)-.5)
    MAX=min(1,as.numeric(input$OneTwo)+.5)
    dom5=dom4[MIN<=dom4[,5] & dom4[,5]<=MAX,]}
  if (as.numeric(input$OneTwo)==0){dom5=dom4[dom4[,5]==0,]}
  
  if (as.numeric(input$TwoTwo)!=0){
    MIN=max(0,as.numeric(input$TwoTwo)-.5)
    MAX=min(1,as.numeric(input$TwoTwo)+.5)
    dom6=dom5[MIN<=dom5[,6] & dom5[,6]<=MAX,]}
  if (as.numeric(input$TwoTwo)==0){dom6=dom5[dom5[,6]==0,]}
  
  if (as.numeric(input$ThreeTwo)!=0){
    MIN=max(0,as.numeric(input$ThreeTwo)-.5)
    MAX=min(1,as.numeric(input$ThreeTwo)+.5)
    dom7=dom6[MIN<=dom6[,7] & dom6[,7]<=MAX,]}
  if (as.numeric(input$ThreeTwo)==0){dom7=dom6[dom6[,7]==0,]}
  
  if (as.numeric(input$FourTwo)!=0){
    MIN=max(0,as.numeric(input$FourTwo)-.5)
    MAX=min(1,as.numeric(input$FourTwo)+.5)
    dom8=dom7[MIN<=dom7[,8] & dom7[,8]<=MAX,]}
  if (as.numeric(input$FourTwo)==0){dom8=dom7[dom7[,8]==0,]}
  
  if (as.numeric(input$OneThree)!=0){
    MIN=max(0,as.numeric(input$OneThree)-.5)
    MAX=min(1,as.numeric(input$OneThree)+.5)
    dom9=dom8[MIN<=dom8[,9] & dom8[,9]<=MAX,]}
  if (as.numeric(input$OneThree)==0){dom9=dom8[dom8[,9]==0,]}
  
  if (as.numeric(input$TwoThree)!=0){
    MIN=max(0,as.numeric(input$TwoThree)-.5)
    MAX=min(1,as.numeric(input$TwoThree)+.5)
    dom10=dom9[MIN<=dom9[,10] & dom9[,10]<=MAX,]}
  if (as.numeric(input$ThreeTwo)==0){dom10=dom9[dom9[,10]==0,]}
  
  if (as.numeric(input$ThreeThree)!=0){
    MIN=max(0,as.numeric(input$ThreeThree)-.5)
    MAX=min(1,as.numeric(input$ThreeThree)+.5)
    dom11=dom10[MIN<=dom10[,11] & dom10[,11]<=MAX,]}
  if (as.numeric(input$ThreeThree)==0){dom11=dom10[dom10[,11]==0,]}
  
  if (as.numeric(input$FourThree)!=0){
    MIN=max(0,as.numeric(input$FourThree)-.5)
    MAX=min(1,as.numeric(input$FourThree)+.5)
    dom12=dom11[MIN<=dom11[,12] & dom11[,12]<=MAX,]}
  if (as.numeric(input$FourThree)==0){dom12=dom11[dom11[,12]==0,]}
  
  if (as.numeric(input$OneFour)!=0){
    MIN=max(0,as.numeric(input$OneFour)-.5)
    MAX=min(1,as.numeric(input$OneFour)+.5)
    dom13=dom12[MIN<=dom12[,13] & dom12[,13]<=MAX,]}
  if (as.numeric(input$OneFour)==0){dom13=dom12[dom12[,13]==0,]}
  
  if (as.numeric(input$TwoFour)!=0){
    MIN=max(0,as.numeric(input$TwoFour)-.5)
    MAX=min(1,as.numeric(input$TwoFour)+.5)
    dom14=dom13[MIN<=dom13[,14] & dom13[,14]<=MAX,]}
  if (as.numeric(input$TwoFour)==0){dom14=dom13[dom13[,14]==0,]}
  
  if (as.numeric(input$ThreeFour)!=0){
    MIN=max(0,as.numeric(input$ThreeFour)-.5)
    MAX=min(1,as.numeric(input$ThreeFour)+.5)
    dom15=dom14[MIN<=dom14[,15] & dom14[,15]<=MAX,]}
  if (as.numeric(input$ThreeFour)==0){dom15=dom14[dom14[,15]==0,]}
  
  if (as.numeric(input$FourFour)!=0){
    MIN=max(0,as.numeric(input$FourFour)-.5)
    MAX=min(1,as.numeric(input$FourFour)+.5)
    candidates=dom15[MIN<=dom15[,16] & dom15[,16]<=MAX,]}
  if (as.numeric(input$FourFour)==0){candidates=dom15[dom15[,16]==0,]}
  
  # Main body 
  
  ref=candidates
  
  NUM.CANDIDATE.MODELS=length(candidates[,1]) 
  First.step.cohort=matrix(0,4+2,NUM.CANDIDATE.MODELS) 			  
  First.step.cohort[4+2,]=1:NUM.CANDIDATE.MODELS	
  TotalN=numeric(as.numeric(input$T)+1)
  
  if (dim(ref)[1]!=0){    
    MODEL.OPTION=0
    for (g in 1:NUM.CANDIDATE.MODELS){ # candidate models [g]
      MODEL.OPTION=MODEL.OPTION+1
      
      # Create the model matrix							
      r1=candidates[g,1]
      r2=candidates[g,2]
      r3=candidates[g,3]
      r4=candidates[g,4]
      a=candidates[g,5]
      b=candidates[g,6]
      c=candidates[g,7]
      d=candidates[g,8]
      e=candidates[g,9]
      f=candidates[g,10]
      gg=candidates[g,11]
      hh=candidates[g,12]
      ii=candidates[g,13]
      jj=candidates[g,14]
      kk=candidates[g,15]
      ll=candidates[g,16]
      top=c(r1,r2,r3,r4)
      mid=c(a,b,c,d)
      mid2=c(e,f,gg,h)
      bot1=c(ii,jj,kk,ll)        
      L=rbind(top,mid,mid2,bot1)
      
      # Get the eigenvalues of the matrix only if there are any to get
      if(dim(ref)[1]!=0){
        L1=eigen(L)$values[1]
        W1=matrix(c(eigen(L)$vectors[,1]),4,1)}
      if(dim(ref)[1]==0){
        L1=0; W1=matrix(c(1,1,1),4,1)}
      
      Proportions.for.W=numeric(4)						        	
      Proportions.for.W[1]=Re(W1[1]/sum(W1))							
      Proportions.for.W[2]=Re(W1[2]/sum(W1))						
      Proportions.for.W[3]=Re(W1[3]/sum(W1))
      Proportions.for.W[4]=Re(W1[4]/sum(W1))						
      
      N=matrix(0,4,(as.numeric(input$T)+1))	
      
      # If 4th stage reproduces							
      if (candidates[g,1]==0){
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
            TotalN=numeric(((as.numeric(input$T)+1)))
            TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}} # end 
      
      # If 3RD stage reproduces							
      if (candidates[g,1]==0){
        if (candidates[g,2]==0){
          if (candidates[g,4]==0){
            N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
            TotalN=numeric(((as.numeric(input$T)+1)))
            TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}} # end 
      
      # If 2ND stage reproduces							
      if (candidates[g,1]==0){
        if (candidates[g,3]==0){
          if (candidates[g,4]==0){
            N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
            TotalN=numeric(((as.numeric(input$T)+1)))
            TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          }}} # end 
      
      # If 1ST stage reproduces							
      if (candidates[g,2]==0){
        if (candidates[g,3]==0){
          if (candidates[g,4]==0){
            N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
            TotalN=numeric(((as.numeric(input$T)+1)))
            TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
            N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          }}} # end 
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]==0){
            if (candidates[g,4]==0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
              TotalN[as.numeric(input$T)+1]=Y
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              # fill in the last value
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            }}}} # end     
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]==0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]==0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
              TotalN[as.numeric(input$T)+1]=Y
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              # fill in the last value
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            }}}} # end        
      #						
      if (candidates[g,1]!=0){
        if (candidates[g,2]==0){
          if (candidates[g,3]==0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
              TotalN[as.numeric(input$T)+1]=Y
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              # fill in the last value
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}}} # end        
      #							
      if (candidates[g,1]==0){
        if (candidates[g,2]==0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
              TotalN[as.numeric(input$T)+1]=Y
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              # fill in the last value
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}}} # end        
      
      #							
      if (candidates[g,1]==0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]==0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
              TotalN[as.numeric(input$T)+1]=Y
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              # fill in the last value
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            }}}} # end        
      #							
      if (candidates[g,1]==0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]==0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
              TotalN[as.numeric(input$T)+1]=Y
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              # fill in the last value
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            }}}} # end 
      #							
      if (candidates[g,1]==0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
              TotalN[as.numeric(input$T)+1]=Y
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              # fill in the last value
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
            }}}} # end        
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]==0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
              TotalN[as.numeric(input$T)+1]=Y
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              # fill in the last value
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}}} # end        
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]==0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
              TotalN[as.numeric(input$T)+1]=Y
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              # fill in the last value
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
            }}}} # end        
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]==0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
              TotalN[as.numeric(input$T)+1]=Y
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              # fill in the last value
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
            }}}} # end        
      
      #							
      if (candidates[g,1]!=0){
        if (candidates[g,2]!=0){
          if (candidates[g,3]!=0){
            if (candidates[g,4]!=0){
              # split of animals given the SSD and the goal
              Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
              TotalN[as.numeric(input$T)+1]=Y
              N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
              N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
              N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
              N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
            }}}} # end        
      
      ##################
      for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
        N[4,x]=floor(Re(N[4,x+1]/L1))
        N[3,x]=floor(Re(N[3,x+1]/L1))
        N[2,x]=floor(Re(N[2,x+1]/L1))
        N[1,x]=floor(Re(N[1,x+1]/L1))
      } # Generating SSD abundances back through time 
      
      # Set the negative numbers to zero
      for (ww in 1:length(N[1,])){
        for (ccc in 1:4){									
          if (N[ccc,ww]<0){N[ccc,ww]=0}}}
      
      for (x in as.numeric(input$T):1){   #calculating the total size at time 0.   
        TotalN[x]=sum(floor(N[4,x])+floor(N[3,x])+floor(N[2,x])+floor(N[1,x]))}       
      
      First.step.cohort[1:4,MODEL.OPTION]=N[,1]					
      First.step.cohort[5,MODEL.OPTION]=floor(TotalN[1])
      candidates[g,18]=floor(TotalN[1])							
    } # end g loop
    
  } # end no candidates loop
  
  # pick out the top best models given user input
  if (dim(ref)[1]!=0){
    if (length(candidates[,1])!=1){
      First.step.cohort[6,]=1:length(candidates[,1])
      best=First.step.cohort[,order(First.step.cohort[5,],decreasing = FALSE)]
      models.to.pick.out=best[6,1:min((length(candidates[,1])),(as.numeric(input$CandidateModels)-1))]}
    
    if (length(candidates[,1])==1){
      First.step.cohort[6,1]=1
      best=First.step.cohort[6,1]
      models.to.pick.out=best}
  }
  if (dim(ref)[1]==0){models.to.pick.out=1}
  
  #Calculate everything for my model, then add it into the top of the best models
  my.model=c(as.numeric(input$M1),as.numeric(input$M2),as.numeric(input$M3),as.numeric(input$M4),
             as.numeric(input$OneTwo),as.numeric(input$TwoTwo),as.numeric(input$ThreeTwo),as.numeric(input$FourTwo),
             as.numeric(input$OneThree),as.numeric(input$TwoThree),as.numeric(input$ThreeThree),as.numeric(input$FourThree),
             as.numeric(input$OneFour),as.numeric(input$TwoFour),as.numeric(input$ThreeFour),as.numeric(input$FourFour))    
  r11=as.numeric(input$M1)
  r21=as.numeric(input$M2)
  r31=as.numeric(input$M3)
  r41=as.numeric(input$M4)
  
  a1=as.numeric(input$OneTwo)
  b1=as.numeric(input$TwoTwo)
  c1=as.numeric(input$ThreeTwo)
  d1=as.numeric(input$FourTwo)
  
  f1=as.numeric(input$OneThree)
  gg1=as.numeric(input$TwoThree)
  h1=as.numeric(input$ThreeThree)
  i1=as.numeric(input$FourThree)
  
  k1=as.numeric(input$OneFour)
  l1=as.numeric(input$TwoFour)
  m1=as.numeric(input$ThreeFour)
  n1=as.numeric(input$FourFour)
  
  top=c(r11,r21,r31,r41)
  mid=c(a1,b1,c1,d1)
  mid2=c(f1,gg1,h1,i1)
  bot1=c(k1,l1,m1,n1)
  L.mine=rbind(top,mid,mid2,bot1)
  
  # Get the eigenvalues of the matrix
  L1=eigen(L.mine)$values[1]
  W1=matrix(c(eigen(L.mine)$vectors[,1]),4,1)
  
  Proportions.for.W=numeric(4)						        
  Proportions.for.W[1]=Re(W1[1]/sum(W1))							
  Proportions.for.W[2]=Re(W1[2]/sum(W1))						
  Proportions.for.W[3]=Re(W1[3]/sum(W1))						
  Proportions.for.W[4]=Re(W1[4]/sum(W1))						
  
  N=matrix(0,4,(as.numeric(input$T)+1))
  # If 4th stage reproduces							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        N[4,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
        TotalN=numeric(((as.numeric(input$T)+1)))
        TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[4])
        N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
        N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
      }}} # end 
  # If 3RD stage reproduces							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M4)==0){
        N[3,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
        TotalN=numeric(((as.numeric(input$T)+1)))
        TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[3])
        N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
      }}} # end 
  # If 2ND stage reproduces							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M3)==0){
      if (as.numeric(input$M4)==0){
        N[2,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
        TotalN=numeric(((as.numeric(input$T)+1)))
        TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[2])
        N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
        N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
      }}} # end 
  # If 1ST stage reproduces							
  if (as.numeric(input$M2)==0){
    if (as.numeric(input$M3)==0){
      if (as.numeric(input$M4)==0){
        N[1,(as.numeric(input$T)+1)]=floor(Re(as.numeric(input$GoalN)))
        TotalN=numeric(((as.numeric(input$T)+1)))
        TotalN[as.numeric(input$T)+1]=floor(as.numeric(input$GoalN)/Proportions.for.W[1])
        N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
        N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
      }}} # end 
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)==0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[2]))
          TotalN[as.numeric(input$T)+1]=Y
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          # fill in the last value
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        }}}} # end     
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)==0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]))
          TotalN[as.numeric(input$T)+1]=Y
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          # fill in the last value
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        }}}} # end        
  #						
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[4]))
          TotalN[as.numeric(input$T)+1]=Y
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          # fill in the last value
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}}} # end        
  #							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]))
          TotalN[as.numeric(input$T)+1]=Y
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          # fill in the last value
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}}} # end        
  #							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[2]))
          TotalN[as.numeric(input$T)+1]=Y
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          # fill in the last value
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
        }}}} # end        
  #							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)==0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[3]+Proportions.for.W[2]))
          TotalN[as.numeric(input$T)+1]=Y
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          # fill in the last value
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        }}}} # end 
  #							
  if (as.numeric(input$M1)==0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[2]))
          TotalN[as.numeric(input$T)+1]=Y
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          # fill in the last value
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
        }}}} # end        
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)==0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[4]+Proportions.for.W[3]+Proportions.for.W[1]))
          TotalN[as.numeric(input$T)+1]=Y
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          # fill in the last value
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}}} # end        
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)==0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[4]+Proportions.for.W[1]))
          TotalN[as.numeric(input$T)+1]=Y
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          # fill in the last value
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
        }}}} # end        
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)==0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[2]+Proportions.for.W[3]+Proportions.for.W[1]))
          TotalN[as.numeric(input$T)+1]=Y
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          # fill in the last value
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
        }}}} # end        
  #							
  if (as.numeric(input$M1)!=0){
    if (as.numeric(input$M2)!=0){
      if (as.numeric(input$M3)!=0){
        if (as.numeric(input$M4)!=0){
          # split of animals given the SSD and the goal
          Y=floor(as.numeric(input$GoalN)/(Proportions.for.W[1]+Proportions.for.W[3]+Proportions.for.W[4]+Proportions.for.W[2]))
          TotalN[as.numeric(input$T)+1]=Y
          N[3,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[3])
          N[4,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[4])
          N[1,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[1])
          N[2,(as.numeric(input$T)+1)]=floor(TotalN[as.numeric(input$T)+1]*Proportions.for.W[2])
        }}}} # end        
  
  ####################################################################################
  for (x in as.numeric(input$T):1){ # Generating SSD abundances back through time 
    N[4,x]=floor(Re(N[4,x+1]/L1))
    N[3,x]=floor(Re(N[3,x+1]/L1))
    N[2,x]=floor(Re(N[2,x+1]/L1))
    N[1,x]=floor(Re(N[1,x+1]/L1))
  } # Generating SSD abundances back through time 
  
  # Set the negative numbers to zero
  for (ccc in 1:4){									
    if (N[ccc,1]<0){N[ccc,1]=0}}
  
  total=sum(floor(N[4,1]),floor(N[1,1]),floor(N[2,1]),floor(N[3,1]))
  
  aaa=as.numeric(input$M1)
  bbb=as.numeric(input$M2)
  cccc=as.numeric(input$M3)
  ddd=as.numeric(input$M4)
  fff=as.numeric(input$OneTwo)
  ggg=as.numeric(input$TwoTwo)
  hhh=as.numeric(input$ThreeTwo)
  iii=as.numeric(input$FourTwo)
  kkk=as.numeric(input$OneThree)
  lll=as.numeric(input$TwoThree)
  mmm=as.numeric(input$ThreeThree)
  nnn=as.numeric(input$FourThree)
  ppp=as.numeric(input$OneFour)
  qqq=as.numeric(input$TwoFour)
  rrr=as.numeric(input$ThreeFour)
  sss=as.numeric(input$FourFour)    
  
  mine=c(aaa,bbb,cccc,ddd,fff,ggg,hhh,iii,kkk,lll,mmm,nnn,ppp,qqq,rrr,sss,Re(L1),floor(total))
  new=rbind(mine,dom[1,]) 
  if (dim(ref)[1]!=0){OPTIMAL.MODELS.ANIMALS1=rbind(as.numeric(mine), candidates[c(models.to.pick.out),])}
  if (dim(ref)[1]==0){OPTIMAL.MODELS.ANIMALS1=new[-2,]}
  
  # End main body  
  
  # Beginning tab specific  
  print(OPTIMAL.MODELS.ANIMALS1,row.names = c(1:length(OPTIMAL.MODELS.ANIMALS1[,1])))
}) # end optimal models tab

} # End server function

shinyApp(ui=ui,server=server)
